Role Name
=========

A role that installs the CKAN catalogue portal, <https://ckan.org>

Role Variables
--------------

The most important variables are listed below:

``` yaml
ckan_version: 2.6
ckan_db_name: ckan
ckan_db_user: ckan
# By default, initialize the db and solr. Disable if you want to reinstall and maintain the old data
ckan_init_db_and_solr: True
#
ckan_clear_harvesting_enabled: True
ckan_clear_harvesting_freq: 'weekly'
# CKAN plugins
ckan_plugins_state: present
# yes: update the repository. no, do not update
ckan_git_plugins_state: 'no'
# Order is important
ckan_geonetwork_harvester: False
ckan_geoview: False
ckan_dcat: False
# dcat implement harvesters too.
# ckan_dcat_name: 'dcat dcat_rdf_harvester dcat_json_harvester dcat_json_interface'
ckan_dcat_name: 'dcat dcat_json_interface'
# Set this to true to install a cron job that regularly runs the harvesters
ckan_harvester_run: False
ckan_pdfview: False
ckan_ckanext_pdfview_url: ckanext-pdfview
ckan_privatedatasets: False
ckan_privatedatasets_url: ckanext-privatedatasets
ckan_privatedatasets_name: privatedatasets
ckan_hierarchy: False
ckan_hierarchy_name: hierarchy_display hierarchy_form
ckan_pages: False
ckan_pages_name: pages
ckan_ldap: False
ckan_ldap_name: ldap
ckan_ldap_uri: 'ldap://ldap.example.org'
ckan_ldap_base_dn: ''
ckan_ldap_search_filter: 'uid={login}'
ckan_ldap_user_fullname: 'cn'
ckan_ldap_username: uid
ckan_ldap_email: mail
ckan_ldap_prevent_edits: True
ckan_ldap_fallback: True
ckan_ckanext_lire: False
ckan_ckanext_lire_n: lire
# Kata OAI-PMH
ckan_kata_oai_pmh: False
ckan_oai_pmh_name: oaipmh
ckan_oai_pmh_state: absent
ckan_oai_pmh_kata_ini_state: 'present'
ckan_oai_pm: False
ckan_oai_pm_name: oaipmh
ckan_oai_pm_state: absent
# Google analytics
ckan_google_analytics: False
ckan_ga_plugin_state: '{{ ckan_plugins_state }}'
ckan_google_analytics_name: googleanalytics
#CKANEXT-RATING
ckan_star_ratings: False
ckan_star_ratings_state: present
ckan_star_ratings_name: rating
ckan_memcache_sessions: False
# Google analytics reports
ckan_ga_reports: False
ckan_profiler: False
# CKAN-DATESEARCH
ckan_datesearch: False
ckan_datesearch_state: present
ckan_production_ini_opts:
  - { section: 'app:main', option: 'ckan.site_id', value: 'ckan_installation', state: 'present' }
  - { section: 'app:main', option: 'sqlalchemy.url', value: 'postgresql://{{ ckan_db_user }}:{{ ckan_db_pwd }}@{{ psql_db_host }}/{{ ckan_db_name }}', state: 'present' }
  - { section: 'app:main', option: 'ckan.site_url', value: 'http://{{ ansible_fqdn }}', state: 'present' }
  - { section: 'app:main', option: 'solr_url', value: 'http://127.0.0.1:{{ ckan_solr_port }}/solr', state: 'present' }
  - { section: 'app:main', option: 'ckan.datastore.write_url', value: 'postgresql://{{ ckan_db_user }}:{{ ckan_db_pwd }}@{{ psql_db_host }}/{{ ckan_datastore_db_name }}', state: 'present' }
  - { section: 'app:main', option: 'ckan.datastore.read_url', value: 'postgresql://{{ ckan_datastore_db_reader }}:{{ ckan_db_pwd }}@{{ psql_db_host }}/{{ ckan_datastore_db_name }}', state: 'present' }
  - { section: 'app:main', option: 'ckan.site_title', value: 'D4Science CKAN development installation', state: 'present' }
  - { section: 'app:main', option: 'ckan.site_logo', value: '/base/images/ckan-logo.png', state: 'present' }
  - { section: 'app:main', option: 'ckan.max_resource_size', value: '10', state: 'present' }
  - { section: 'app:main', option: 'ckan.max_image_size', value: '2', state: 'present' }
  - { section: 'app:main', option: 'ckan.tracking_enabled', value: 'true', state: 'present' }
  - { section: 'app:main', option: 'ckan.privatedatasets.show_acquire_url_on_create', value: 'true', state: 'present' }
  - { section: 'app:main', option: 'ckan.privatedatasets.show_acquire_url_on_edit', value: 'true', state: 'present' }

ckan_production_ini_plugins_opts:
  - { section: 'app:main', option: 'ckan.plugins', value: 'stats text_view image_view recline_view datastore datapusher harvest', state: 'present' }
  - { section: 'app:main', option: 'ckan.datapusher.url', value: 'http://127.0.0.1:8800', state: 'present' }
  - { section: 'app:main', option: 'ckan.datapusher.formats', value: 'csv xls xlsx tsv application/csv application/vnd.ms-excel application/vnd.openxmlformats-officedocument.spreadsheetml.sheet', state: 'present' }
  - { section: 'app:main', option: 'ckan.storage_path', value: '{{ ckan_file_storage_dir }}', state: 'present' }
  - { section: 'app:main', option: 'ckan.harvest.mq.type', value: 'redis', state: 'present' }
  - { section: 'app:main', option: 'ckan.harvest.mq.hostname', value: 'localhost', state: 'present' }
  - { section: 'app:main', option: 'ckan.harvest.mq.port', value: '6379', state: 'present' }
  - { section: 'app:main', option: 'ckan.harvest.mq.db', value: '0', state: 'present' }
  - { section: 'app:main', option: 'ckanext.spatial.search_backend', value: 'solr', state: 'present' }
  - { section: 'app:main', option: 'ckanext.pages.organization', value: 'true', state: 'present' }
  - { section: 'app:main', option: 'ckanext.pages.group', value: 'true', state: 'present' }
  - { section: 'app:main', option: 'ckanext.pages.about_menu', value: 'false', state: 'absent' }
  - { section: 'app:main', option: 'ckanext.pages.group_menu', value: 'false', state: 'absent' }
  - { section: 'app:main', option: 'ckanext.pages.organization_menu', value: 'false', state: 'absent' }
```

Dependencies
------------

None

License
-------

EUPL-1.2

Author Information
------------------

Andrea Dell'Amico, <andrea.dellamico@isti.cnr.it>
